platform

package
v1.5.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var UpdatePlatformReq_IsDefault_DEFAULT bool
var UpdatePlatformReq_SkipTlsVerify_DEFAULT bool

Functions

This section is empty.

Types

type CreatePlatformReq

type CreatePlatformReq struct {
	Name          string `thrift:"name,1" form:"name" json:"name" query:"name"`
	Type          string `thrift:"type,2" form:"type" json:"type" query:"type"`
	InstanceUrl   string `thrift:"instanceUrl,3" form:"instance_url" json:"instance_url" query:"instance_url"`
	ApiUrl        string `thrift:"apiUrl,4" form:"api_url" json:"api_url" query:"api_url"`
	AccessToken   string `thrift:"accessToken,5" form:"access_token" json:"access_token" query:"access_token"`
	SkipTlsVerify bool   `thrift:"skipTlsVerify,6" form:"skip_tls_verify" json:"skip_tls_verify" query:"skip_tls_verify"`
	CaCertPath    string `thrift:"caCertPath,7" form:"ca_cert_path" json:"ca_cert_path" query:"ca_cert_path"`
	ProxyUrl      string `thrift:"proxyUrl,8" form:"proxy_url" json:"proxy_url" query:"proxy_url"`
	IsDefault     bool   `thrift:"isDefault,9" form:"is_default" json:"is_default" query:"is_default"`
}

func NewCreatePlatformReq

func NewCreatePlatformReq() *CreatePlatformReq

func (*CreatePlatformReq) GetAccessToken

func (p *CreatePlatformReq) GetAccessToken() (v string)

func (*CreatePlatformReq) GetApiUrl

func (p *CreatePlatformReq) GetApiUrl() (v string)

func (*CreatePlatformReq) GetCaCertPath

func (p *CreatePlatformReq) GetCaCertPath() (v string)

func (*CreatePlatformReq) GetInstanceUrl

func (p *CreatePlatformReq) GetInstanceUrl() (v string)

func (*CreatePlatformReq) GetIsDefault

func (p *CreatePlatformReq) GetIsDefault() (v bool)

func (*CreatePlatformReq) GetName

func (p *CreatePlatformReq) GetName() (v string)

func (*CreatePlatformReq) GetProxyUrl

func (p *CreatePlatformReq) GetProxyUrl() (v string)

func (*CreatePlatformReq) GetSkipTlsVerify

func (p *CreatePlatformReq) GetSkipTlsVerify() (v bool)

func (*CreatePlatformReq) GetType

func (p *CreatePlatformReq) GetType() (v string)

func (*CreatePlatformReq) InitDefault

func (p *CreatePlatformReq) InitDefault()

func (*CreatePlatformReq) Read

func (p *CreatePlatformReq) Read(iprot thrift.TProtocol) (err error)

func (*CreatePlatformReq) ReadField1

func (p *CreatePlatformReq) ReadField1(iprot thrift.TProtocol) error

func (*CreatePlatformReq) ReadField2

func (p *CreatePlatformReq) ReadField2(iprot thrift.TProtocol) error

func (*CreatePlatformReq) ReadField3

func (p *CreatePlatformReq) ReadField3(iprot thrift.TProtocol) error

func (*CreatePlatformReq) ReadField4

func (p *CreatePlatformReq) ReadField4(iprot thrift.TProtocol) error

func (*CreatePlatformReq) ReadField5

func (p *CreatePlatformReq) ReadField5(iprot thrift.TProtocol) error

func (*CreatePlatformReq) ReadField6

func (p *CreatePlatformReq) ReadField6(iprot thrift.TProtocol) error

func (*CreatePlatformReq) ReadField7

func (p *CreatePlatformReq) ReadField7(iprot thrift.TProtocol) error

func (*CreatePlatformReq) ReadField8

func (p *CreatePlatformReq) ReadField8(iprot thrift.TProtocol) error

func (*CreatePlatformReq) ReadField9

func (p *CreatePlatformReq) ReadField9(iprot thrift.TProtocol) error

func (*CreatePlatformReq) String

func (p *CreatePlatformReq) String() string

func (*CreatePlatformReq) Write

func (p *CreatePlatformReq) Write(oprot thrift.TProtocol) (err error)

type CreatePlatformResp

type CreatePlatformResp struct {
	Platform *PlatformInfo `thrift:"platform,1" form:"platform" json:"platform" query:"platform"`
}

func NewCreatePlatformResp

func NewCreatePlatformResp() *CreatePlatformResp

func (*CreatePlatformResp) GetPlatform

func (p *CreatePlatformResp) GetPlatform() (v *PlatformInfo)

func (*CreatePlatformResp) InitDefault

func (p *CreatePlatformResp) InitDefault()

func (*CreatePlatformResp) IsSetPlatform

func (p *CreatePlatformResp) IsSetPlatform() bool

func (*CreatePlatformResp) Read

func (p *CreatePlatformResp) Read(iprot thrift.TProtocol) (err error)

func (*CreatePlatformResp) ReadField1

func (p *CreatePlatformResp) ReadField1(iprot thrift.TProtocol) error

func (*CreatePlatformResp) String

func (p *CreatePlatformResp) String() string

func (*CreatePlatformResp) Write

func (p *CreatePlatformResp) Write(oprot thrift.TProtocol) (err error)

type DeletePlatformReq

type DeletePlatformReq struct {
	Key string `thrift:"key,1" json:"key" query:"key"`
}

func NewDeletePlatformReq

func NewDeletePlatformReq() *DeletePlatformReq

func (*DeletePlatformReq) GetKey

func (p *DeletePlatformReq) GetKey() (v string)

func (*DeletePlatformReq) InitDefault

func (p *DeletePlatformReq) InitDefault()

func (*DeletePlatformReq) Read

func (p *DeletePlatformReq) Read(iprot thrift.TProtocol) (err error)

func (*DeletePlatformReq) ReadField1

func (p *DeletePlatformReq) ReadField1(iprot thrift.TProtocol) error

func (*DeletePlatformReq) String

func (p *DeletePlatformReq) String() string

func (*DeletePlatformReq) Write

func (p *DeletePlatformReq) Write(oprot thrift.TProtocol) (err error)

type DeletePlatformResp

type DeletePlatformResp struct {
	Success bool `thrift:"success,1" form:"success" json:"success" query:"success"`
}

func NewDeletePlatformResp

func NewDeletePlatformResp() *DeletePlatformResp

func (*DeletePlatformResp) GetSuccess

func (p *DeletePlatformResp) GetSuccess() (v bool)

func (*DeletePlatformResp) InitDefault

func (p *DeletePlatformResp) InitDefault()

func (*DeletePlatformResp) Read

func (p *DeletePlatformResp) Read(iprot thrift.TProtocol) (err error)

func (*DeletePlatformResp) ReadField1

func (p *DeletePlatformResp) ReadField1(iprot thrift.TProtocol) error

func (*DeletePlatformResp) String

func (p *DeletePlatformResp) String() string

func (*DeletePlatformResp) Write

func (p *DeletePlatformResp) Write(oprot thrift.TProtocol) (err error)

type GetPlatformReq

type GetPlatformReq struct {
	Key string `thrift:"key,1" json:"key" query:"key"`
}

func NewGetPlatformReq

func NewGetPlatformReq() *GetPlatformReq

func (*GetPlatformReq) GetKey

func (p *GetPlatformReq) GetKey() (v string)

func (*GetPlatformReq) InitDefault

func (p *GetPlatformReq) InitDefault()

func (*GetPlatformReq) Read

func (p *GetPlatformReq) Read(iprot thrift.TProtocol) (err error)

func (*GetPlatformReq) ReadField1

func (p *GetPlatformReq) ReadField1(iprot thrift.TProtocol) error

func (*GetPlatformReq) String

func (p *GetPlatformReq) String() string

func (*GetPlatformReq) Write

func (p *GetPlatformReq) Write(oprot thrift.TProtocol) (err error)

type GetPlatformResp

type GetPlatformResp struct {
	Platform *PlatformInfo `thrift:"platform,1" form:"platform" json:"platform" query:"platform"`
}

func NewGetPlatformResp

func NewGetPlatformResp() *GetPlatformResp

func (*GetPlatformResp) GetPlatform

func (p *GetPlatformResp) GetPlatform() (v *PlatformInfo)

func (*GetPlatformResp) InitDefault

func (p *GetPlatformResp) InitDefault()

func (*GetPlatformResp) IsSetPlatform

func (p *GetPlatformResp) IsSetPlatform() bool

func (*GetPlatformResp) Read

func (p *GetPlatformResp) Read(iprot thrift.TProtocol) (err error)

func (*GetPlatformResp) ReadField1

func (p *GetPlatformResp) ReadField1(iprot thrift.TProtocol) error

func (*GetPlatformResp) String

func (p *GetPlatformResp) String() string

func (*GetPlatformResp) Write

func (p *GetPlatformResp) Write(oprot thrift.TProtocol) (err error)

type ListPlatformReposReq

type ListPlatformReposReq struct {
	Key     string `thrift:"key,1" json:"key" query:"key"`
	Page    string `thrift:"page,2" json:"page" query:"page"`
	PerPage string `thrift:"perPage,3" json:"per_page" query:"per_page"`
}

func NewListPlatformReposReq

func NewListPlatformReposReq() *ListPlatformReposReq

func (*ListPlatformReposReq) GetKey

func (p *ListPlatformReposReq) GetKey() (v string)

func (*ListPlatformReposReq) GetPage

func (p *ListPlatformReposReq) GetPage() (v string)

func (*ListPlatformReposReq) GetPerPage

func (p *ListPlatformReposReq) GetPerPage() (v string)

func (*ListPlatformReposReq) InitDefault

func (p *ListPlatformReposReq) InitDefault()

func (*ListPlatformReposReq) Read

func (p *ListPlatformReposReq) Read(iprot thrift.TProtocol) (err error)

func (*ListPlatformReposReq) ReadField1

func (p *ListPlatformReposReq) ReadField1(iprot thrift.TProtocol) error

func (*ListPlatformReposReq) ReadField2

func (p *ListPlatformReposReq) ReadField2(iprot thrift.TProtocol) error

func (*ListPlatformReposReq) ReadField3

func (p *ListPlatformReposReq) ReadField3(iprot thrift.TProtocol) error

func (*ListPlatformReposReq) String

func (p *ListPlatformReposReq) String() string

func (*ListPlatformReposReq) Write

func (p *ListPlatformReposReq) Write(oprot thrift.TProtocol) (err error)

type ListPlatformReposResp

type ListPlatformReposResp struct {
	Total int32 `thrift:"total,1" form:"total" json:"total" query:"total"`
}

func NewListPlatformReposResp

func NewListPlatformReposResp() *ListPlatformReposResp

func (*ListPlatformReposResp) GetTotal

func (p *ListPlatformReposResp) GetTotal() (v int32)

func (*ListPlatformReposResp) InitDefault

func (p *ListPlatformReposResp) InitDefault()

func (*ListPlatformReposResp) Read

func (p *ListPlatformReposResp) Read(iprot thrift.TProtocol) (err error)

func (*ListPlatformReposResp) ReadField1

func (p *ListPlatformReposResp) ReadField1(iprot thrift.TProtocol) error

func (*ListPlatformReposResp) String

func (p *ListPlatformReposResp) String() string

func (*ListPlatformReposResp) Write

func (p *ListPlatformReposResp) Write(oprot thrift.TProtocol) (err error)

type ListPlatformsReq

type ListPlatformsReq struct {
}

func NewListPlatformsReq

func NewListPlatformsReq() *ListPlatformsReq

func (*ListPlatformsReq) InitDefault

func (p *ListPlatformsReq) InitDefault()

func (*ListPlatformsReq) Read

func (p *ListPlatformsReq) Read(iprot thrift.TProtocol) (err error)

func (*ListPlatformsReq) String

func (p *ListPlatformsReq) String() string

func (*ListPlatformsReq) Write

func (p *ListPlatformsReq) Write(oprot thrift.TProtocol) (err error)

type ListPlatformsResp

type ListPlatformsResp struct {
	Platforms []*PlatformInfo `thrift:"platforms,1,default,list<PlatformInfo>" form:"platforms" json:"platforms" query:"platforms"`
	Total     int64           `thrift:"total,2" form:"total" json:"total" query:"total"`
}

func NewListPlatformsResp

func NewListPlatformsResp() *ListPlatformsResp

func (*ListPlatformsResp) GetPlatforms

func (p *ListPlatformsResp) GetPlatforms() (v []*PlatformInfo)

func (*ListPlatformsResp) GetTotal

func (p *ListPlatformsResp) GetTotal() (v int64)

func (*ListPlatformsResp) InitDefault

func (p *ListPlatformsResp) InitDefault()

func (*ListPlatformsResp) Read

func (p *ListPlatformsResp) Read(iprot thrift.TProtocol) (err error)

func (*ListPlatformsResp) ReadField1

func (p *ListPlatformsResp) ReadField1(iprot thrift.TProtocol) error

func (*ListPlatformsResp) ReadField2

func (p *ListPlatformsResp) ReadField2(iprot thrift.TProtocol) error

func (*ListPlatformsResp) String

func (p *ListPlatformsResp) String() string

func (*ListPlatformsResp) Write

func (p *ListPlatformsResp) Write(oprot thrift.TProtocol) (err error)

type PlatformInfo

type PlatformInfo struct {
	ID             int64  `thrift:"id,1" form:"id" json:"id" query:"id"`
	Key            string `thrift:"key,2" form:"key" json:"key" query:"key"`
	Name           string `thrift:"name,3" form:"name" json:"name" query:"name"`
	Type           string `thrift:"type,4" form:"type" json:"type" query:"type"`
	InstanceUrl    string `thrift:"instanceUrl,5" form:"instance_url" json:"instance_url" query:"instance_url"`
	ApiUrl         string `thrift:"apiUrl,6" form:"api_url" json:"api_url" query:"api_url"`
	SkipTlsVerify  bool   `thrift:"skipTlsVerify,7" form:"skip_tls_verify" json:"skip_tls_verify" query:"skip_tls_verify"`
	CaCertPath     string `thrift:"caCertPath,8" form:"ca_cert_path" json:"ca_cert_path" query:"ca_cert_path"`
	ProxyUrl       string `thrift:"proxyUrl,9" form:"proxy_url" json:"proxy_url" query:"proxy_url"`
	IsDefault      bool   `thrift:"isDefault,10" form:"is_default" json:"is_default" query:"is_default"`
	Status         string `thrift:"status,11" form:"status" json:"status" query:"status"`
	LastTestResult string `thrift:"lastTestResult,12" form:"last_test_result" json:"last_test_result" query:"last_test_result"`
	RepoCount      int32  `thrift:"repoCount,13" form:"repo_count" json:"repo_count" query:"repo_count"`
	CreatedAt      string `thrift:"createdAt,14" form:"created_at" json:"created_at" query:"created_at"`
	LastTestAt     string `thrift:"lastTestAt,15" form:"last_test_at" json:"last_test_at" query:"last_test_at"`
	UpdatedAt      string `thrift:"updatedAt,16" form:"updated_at" json:"updated_at" query:"updated_at"`
}

Platform management IDL. Req fields mirror the existing handler request structs (platform_service.go). Method names match the existing handler functions so hz preserves their business logic on regenerate.

var CreatePlatformResp_Platform_DEFAULT *PlatformInfo
var GetPlatformResp_Platform_DEFAULT *PlatformInfo
var UpdatePlatformResp_Platform_DEFAULT *PlatformInfo

func NewPlatformInfo

func NewPlatformInfo() *PlatformInfo

func (*PlatformInfo) GetApiUrl

func (p *PlatformInfo) GetApiUrl() (v string)

func (*PlatformInfo) GetCaCertPath

func (p *PlatformInfo) GetCaCertPath() (v string)

func (*PlatformInfo) GetCreatedAt

func (p *PlatformInfo) GetCreatedAt() (v string)

func (*PlatformInfo) GetID

func (p *PlatformInfo) GetID() (v int64)

func (*PlatformInfo) GetInstanceUrl

func (p *PlatformInfo) GetInstanceUrl() (v string)

func (*PlatformInfo) GetIsDefault

func (p *PlatformInfo) GetIsDefault() (v bool)

func (*PlatformInfo) GetKey

func (p *PlatformInfo) GetKey() (v string)

func (*PlatformInfo) GetLastTestAt

func (p *PlatformInfo) GetLastTestAt() (v string)

func (*PlatformInfo) GetLastTestResult

func (p *PlatformInfo) GetLastTestResult() (v string)

func (*PlatformInfo) GetName

func (p *PlatformInfo) GetName() (v string)

func (*PlatformInfo) GetProxyUrl

func (p *PlatformInfo) GetProxyUrl() (v string)

func (*PlatformInfo) GetRepoCount

func (p *PlatformInfo) GetRepoCount() (v int32)

func (*PlatformInfo) GetSkipTlsVerify

func (p *PlatformInfo) GetSkipTlsVerify() (v bool)

func (*PlatformInfo) GetStatus

func (p *PlatformInfo) GetStatus() (v string)

func (*PlatformInfo) GetType

func (p *PlatformInfo) GetType() (v string)

func (*PlatformInfo) GetUpdatedAt

func (p *PlatformInfo) GetUpdatedAt() (v string)

func (*PlatformInfo) InitDefault

func (p *PlatformInfo) InitDefault()

func (*PlatformInfo) Read

func (p *PlatformInfo) Read(iprot thrift.TProtocol) (err error)

func (*PlatformInfo) ReadField1

func (p *PlatformInfo) ReadField1(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField2

func (p *PlatformInfo) ReadField2(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField3

func (p *PlatformInfo) ReadField3(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField4

func (p *PlatformInfo) ReadField4(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField5

func (p *PlatformInfo) ReadField5(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField6

func (p *PlatformInfo) ReadField6(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField7

func (p *PlatformInfo) ReadField7(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField8

func (p *PlatformInfo) ReadField8(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField9

func (p *PlatformInfo) ReadField9(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField10

func (p *PlatformInfo) ReadField10(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField11

func (p *PlatformInfo) ReadField11(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField12

func (p *PlatformInfo) ReadField12(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField13

func (p *PlatformInfo) ReadField13(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField14

func (p *PlatformInfo) ReadField14(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField15

func (p *PlatformInfo) ReadField15(iprot thrift.TProtocol) error

func (*PlatformInfo) ReadField16

func (p *PlatformInfo) ReadField16(iprot thrift.TProtocol) error

func (*PlatformInfo) String

func (p *PlatformInfo) String() string

func (*PlatformInfo) Write

func (p *PlatformInfo) Write(oprot thrift.TProtocol) (err error)

type SetDefaultPlatformReq

type SetDefaultPlatformReq struct {
	Key string `thrift:"key,1" json:"key" query:"key"`
}

func NewSetDefaultPlatformReq

func NewSetDefaultPlatformReq() *SetDefaultPlatformReq

func (*SetDefaultPlatformReq) GetKey

func (p *SetDefaultPlatformReq) GetKey() (v string)

func (*SetDefaultPlatformReq) InitDefault

func (p *SetDefaultPlatformReq) InitDefault()

func (*SetDefaultPlatformReq) Read

func (p *SetDefaultPlatformReq) Read(iprot thrift.TProtocol) (err error)

func (*SetDefaultPlatformReq) ReadField1

func (p *SetDefaultPlatformReq) ReadField1(iprot thrift.TProtocol) error

func (*SetDefaultPlatformReq) String

func (p *SetDefaultPlatformReq) String() string

func (*SetDefaultPlatformReq) Write

func (p *SetDefaultPlatformReq) Write(oprot thrift.TProtocol) (err error)

type SetDefaultPlatformResp

type SetDefaultPlatformResp struct {
	Message string `thrift:"message,1" form:"message" json:"message" query:"message"`
}

func NewSetDefaultPlatformResp

func NewSetDefaultPlatformResp() *SetDefaultPlatformResp

func (*SetDefaultPlatformResp) GetMessage

func (p *SetDefaultPlatformResp) GetMessage() (v string)

func (*SetDefaultPlatformResp) InitDefault

func (p *SetDefaultPlatformResp) InitDefault()

func (*SetDefaultPlatformResp) Read

func (p *SetDefaultPlatformResp) Read(iprot thrift.TProtocol) (err error)

func (*SetDefaultPlatformResp) ReadField1

func (p *SetDefaultPlatformResp) ReadField1(iprot thrift.TProtocol) error

func (*SetDefaultPlatformResp) String

func (p *SetDefaultPlatformResp) String() string

func (*SetDefaultPlatformResp) Write

func (p *SetDefaultPlatformResp) Write(oprot thrift.TProtocol) (err error)

type SyncPlatformReposReq

type SyncPlatformReposReq struct {
	Key string `thrift:"key,1" json:"key" query:"key"`
}

func NewSyncPlatformReposReq

func NewSyncPlatformReposReq() *SyncPlatformReposReq

func (*SyncPlatformReposReq) GetKey

func (p *SyncPlatformReposReq) GetKey() (v string)

func (*SyncPlatformReposReq) InitDefault

func (p *SyncPlatformReposReq) InitDefault()

func (*SyncPlatformReposReq) Read

func (p *SyncPlatformReposReq) Read(iprot thrift.TProtocol) (err error)

func (*SyncPlatformReposReq) ReadField1

func (p *SyncPlatformReposReq) ReadField1(iprot thrift.TProtocol) error

func (*SyncPlatformReposReq) String

func (p *SyncPlatformReposReq) String() string

func (*SyncPlatformReposReq) Write

func (p *SyncPlatformReposReq) Write(oprot thrift.TProtocol) (err error)

type SyncPlatformReposResp

type SyncPlatformReposResp struct {
	Message     string `thrift:"message,1" form:"message" json:"message" query:"message"`
	SyncedCount int32  `thrift:"syncedCount,2" form:"synced_count" json:"synced_count" query:"synced_count"`
}

func NewSyncPlatformReposResp

func NewSyncPlatformReposResp() *SyncPlatformReposResp

func (*SyncPlatformReposResp) GetMessage

func (p *SyncPlatformReposResp) GetMessage() (v string)

func (*SyncPlatformReposResp) GetSyncedCount

func (p *SyncPlatformReposResp) GetSyncedCount() (v int32)

func (*SyncPlatformReposResp) InitDefault

func (p *SyncPlatformReposResp) InitDefault()

func (*SyncPlatformReposResp) Read

func (p *SyncPlatformReposResp) Read(iprot thrift.TProtocol) (err error)

func (*SyncPlatformReposResp) ReadField1

func (p *SyncPlatformReposResp) ReadField1(iprot thrift.TProtocol) error

func (*SyncPlatformReposResp) ReadField2

func (p *SyncPlatformReposResp) ReadField2(iprot thrift.TProtocol) error

func (*SyncPlatformReposResp) String

func (p *SyncPlatformReposResp) String() string

func (*SyncPlatformReposResp) Write

func (p *SyncPlatformReposResp) Write(oprot thrift.TProtocol) (err error)

type TestPlatformConnectionReq

type TestPlatformConnectionReq struct {
	Key string `thrift:"key,1" json:"key" query:"key"`
}

func NewTestPlatformConnectionReq

func NewTestPlatformConnectionReq() *TestPlatformConnectionReq

func (*TestPlatformConnectionReq) GetKey

func (p *TestPlatformConnectionReq) GetKey() (v string)

func (*TestPlatformConnectionReq) InitDefault

func (p *TestPlatformConnectionReq) InitDefault()

func (*TestPlatformConnectionReq) Read

func (p *TestPlatformConnectionReq) Read(iprot thrift.TProtocol) (err error)

func (*TestPlatformConnectionReq) ReadField1

func (p *TestPlatformConnectionReq) ReadField1(iprot thrift.TProtocol) error

func (*TestPlatformConnectionReq) String

func (p *TestPlatformConnectionReq) String() string

func (*TestPlatformConnectionReq) Write

func (p *TestPlatformConnectionReq) Write(oprot thrift.TProtocol) (err error)

type TestPlatformConnectionResp

type TestPlatformConnectionResp struct {
	Result string `thrift:"result,1" form:"result" json:"result" query:"result"`
}

func NewTestPlatformConnectionResp

func NewTestPlatformConnectionResp() *TestPlatformConnectionResp

func (*TestPlatformConnectionResp) GetResult

func (p *TestPlatformConnectionResp) GetResult() (v string)

func (*TestPlatformConnectionResp) InitDefault

func (p *TestPlatformConnectionResp) InitDefault()

func (*TestPlatformConnectionResp) Read

func (p *TestPlatformConnectionResp) Read(iprot thrift.TProtocol) (err error)

func (*TestPlatformConnectionResp) ReadField1

func (p *TestPlatformConnectionResp) ReadField1(iprot thrift.TProtocol) error

func (*TestPlatformConnectionResp) String

func (p *TestPlatformConnectionResp) String() string

func (*TestPlatformConnectionResp) Write

func (p *TestPlatformConnectionResp) Write(oprot thrift.TProtocol) (err error)

type UpdatePlatformReq

type UpdatePlatformReq struct {
	Key           string `thrift:"key,1" form:"key" json:"key" query:"key"`
	Name          string `thrift:"name,2" form:"name" json:"name" query:"name"`
	InstanceUrl   string `thrift:"instanceUrl,3" form:"instance_url" json:"instance_url" query:"instance_url"`
	ApiUrl        string `thrift:"apiUrl,4" form:"api_url" json:"api_url" query:"api_url"`
	AccessToken   string `thrift:"accessToken,5" form:"access_token" json:"access_token" query:"access_token"`
	SkipTlsVerify *bool  `thrift:"skipTlsVerify,6,optional" form:"skip_tls_verify" json:"skip_tls_verify,omitempty" query:"skip_tls_verify"`
	CaCertPath    string `thrift:"caCertPath,7" form:"ca_cert_path" json:"ca_cert_path" query:"ca_cert_path"`
	ProxyUrl      string `thrift:"proxyUrl,8" form:"proxy_url" json:"proxy_url" query:"proxy_url"`
	IsDefault     *bool  `thrift:"isDefault,9,optional" form:"is_default" json:"is_default,omitempty" query:"is_default"`
}

func NewUpdatePlatformReq

func NewUpdatePlatformReq() *UpdatePlatformReq

func (*UpdatePlatformReq) GetAccessToken

func (p *UpdatePlatformReq) GetAccessToken() (v string)

func (*UpdatePlatformReq) GetApiUrl

func (p *UpdatePlatformReq) GetApiUrl() (v string)

func (*UpdatePlatformReq) GetCaCertPath

func (p *UpdatePlatformReq) GetCaCertPath() (v string)

func (*UpdatePlatformReq) GetInstanceUrl

func (p *UpdatePlatformReq) GetInstanceUrl() (v string)

func (*UpdatePlatformReq) GetIsDefault

func (p *UpdatePlatformReq) GetIsDefault() (v bool)

func (*UpdatePlatformReq) GetKey

func (p *UpdatePlatformReq) GetKey() (v string)

func (*UpdatePlatformReq) GetName

func (p *UpdatePlatformReq) GetName() (v string)

func (*UpdatePlatformReq) GetProxyUrl

func (p *UpdatePlatformReq) GetProxyUrl() (v string)

func (*UpdatePlatformReq) GetSkipTlsVerify

func (p *UpdatePlatformReq) GetSkipTlsVerify() (v bool)

func (*UpdatePlatformReq) InitDefault

func (p *UpdatePlatformReq) InitDefault()

func (*UpdatePlatformReq) IsSetIsDefault

func (p *UpdatePlatformReq) IsSetIsDefault() bool

func (*UpdatePlatformReq) IsSetSkipTlsVerify

func (p *UpdatePlatformReq) IsSetSkipTlsVerify() bool

func (*UpdatePlatformReq) Read

func (p *UpdatePlatformReq) Read(iprot thrift.TProtocol) (err error)

func (*UpdatePlatformReq) ReadField1

func (p *UpdatePlatformReq) ReadField1(iprot thrift.TProtocol) error

func (*UpdatePlatformReq) ReadField2

func (p *UpdatePlatformReq) ReadField2(iprot thrift.TProtocol) error

func (*UpdatePlatformReq) ReadField3

func (p *UpdatePlatformReq) ReadField3(iprot thrift.TProtocol) error

func (*UpdatePlatformReq) ReadField4

func (p *UpdatePlatformReq) ReadField4(iprot thrift.TProtocol) error

func (*UpdatePlatformReq) ReadField5

func (p *UpdatePlatformReq) ReadField5(iprot thrift.TProtocol) error

func (*UpdatePlatformReq) ReadField6

func (p *UpdatePlatformReq) ReadField6(iprot thrift.TProtocol) error

func (*UpdatePlatformReq) ReadField7

func (p *UpdatePlatformReq) ReadField7(iprot thrift.TProtocol) error

func (*UpdatePlatformReq) ReadField8

func (p *UpdatePlatformReq) ReadField8(iprot thrift.TProtocol) error

func (*UpdatePlatformReq) ReadField9

func (p *UpdatePlatformReq) ReadField9(iprot thrift.TProtocol) error

func (*UpdatePlatformReq) String

func (p *UpdatePlatformReq) String() string

func (*UpdatePlatformReq) Write

func (p *UpdatePlatformReq) Write(oprot thrift.TProtocol) (err error)

type UpdatePlatformResp

type UpdatePlatformResp struct {
	Platform *PlatformInfo `thrift:"platform,1" form:"platform" json:"platform" query:"platform"`
}

func NewUpdatePlatformResp

func NewUpdatePlatformResp() *UpdatePlatformResp

func (*UpdatePlatformResp) GetPlatform

func (p *UpdatePlatformResp) GetPlatform() (v *PlatformInfo)

func (*UpdatePlatformResp) InitDefault

func (p *UpdatePlatformResp) InitDefault()

func (*UpdatePlatformResp) IsSetPlatform

func (p *UpdatePlatformResp) IsSetPlatform() bool

func (*UpdatePlatformResp) Read

func (p *UpdatePlatformResp) Read(iprot thrift.TProtocol) (err error)

func (*UpdatePlatformResp) ReadField1

func (p *UpdatePlatformResp) ReadField1(iprot thrift.TProtocol) error

func (*UpdatePlatformResp) String

func (p *UpdatePlatformResp) String() string

func (*UpdatePlatformResp) Write

func (p *UpdatePlatformResp) Write(oprot thrift.TProtocol) (err error)

Jump to